@@ -6,19 +6,18 @@ def capping(amsh, bias=0, invert=False, res=50):
     bn =  amsh.boundaries().join(reset=True)
 
     pln = fit_plane(bn)
-    cp = [pln.closest_point(p) for p in bn.points()]
+    cp = [pln.closest_point(p) for p in bn.vertices]
     pts = Points(cp)
-    pts.top = pln.normal
 
     if invert is None:
         cutm = amsh.clone().cut_with_plane(origin=pln.center, normal=pln.normal)
         invert = cutm.npoints > amsh.npoints
 
-    pts2 = pts.clone().orientation([0,0,1]).project_on_plane('z')
+    pts2 = pts.clone().reorient(pln.normal, [0,0,1]).project_on_plane('z')
     msh2 = pts2.generate_mesh(invert=invert, mesh_resolution=res)
 
-    source = pts2.points().tolist()
-    target = bn.points().tolist()
+    source = pts2.vertices.tolist()
+    target = bn.vertices.tolist()
     printc(f"..warping {len(source)} points")
     msh3 = msh2.clone().warp(source, target, mode='3d')
 
@@ -28,7 +27,7 @@ def capping(amsh, bias=0, invert=False, res=50):
 
     if bias:
         newpts = []
-        for p in msh3.points():
+        for p in msh3.vertices:
             q = bn.closest_point(p)
             d = mag(p-q)
             newpt = p + d * pln.normal * bias
@@ -37,7 +36,7 @@ def capping(amsh, bias=0, invert=False, res=50):
     return msh3
 
 
-msh = Mesh(dataurl+"260_flank.vtp").c('orange5').bc('purple7').lw(0.1)
+msh = Mesh(dataurl+"260_flank.vtp").c('orange5').bc('purple7').lw(1)
 
 # mcap = msh.cap()  # automatic
 mcap = capping(msh, invert=True)
