@@ -10,7 +10,7 @@ np.random.seed(1)
 
 surf = Grid([0,0,0], res=[25,25])
 ids = np.random.randint(0, surf.npoints, 10)  # pick 10 indices
-pts = surf.points()[ids]
+pts = surf.vertices[ids]
 
 ptsource, pttarget = [], []
 for pt in pts:
@@ -20,9 +20,9 @@ for pt in pts:
     pttarget.append(pt1)
 
 warped = surf.warp(ptsource, pttarget, mode='2d')
-warped.color("b4").lc('lightblue').lw(0.1).wireframe(False)
+warped.color("b4").lc('lightblue').lw(1).wireframe(False)
 
-apts = Points(pttarget, r=15, c="red5")
-arrs = Arrows(ptsource, pttarget, c='k')
+apts = Points(pttarget).point_size(15).c("red5")
+arrs = Arrows(ptsource, pttarget).c("black")
 
 show(warped, apts, arrs, __doc__, axes=1, viewup="z").close()
