@@ -12,22 +12,20 @@ import pymeshfix
 import tetgen
 import vedo
 
-vedo.settings.use_depth_peeling = True
-
 amesh = vedo.Mesh(vedo.dataurl+'290.vtk')
 
 # repairing also closes the mesh in a nice way
-meshfix = pymeshfix.MeshFix(amesh.points(), amesh.faces())
+meshfix = pymeshfix.MeshFix(amesh.vertices, amesh.cells)
 meshfix.repair()
 repaired = vedo.Mesh(meshfix.mesh).linewidth(1).alpha(0.5)
 
 # tetralize the closed surface
-tet = tetgen.TetGen(repaired.points(), repaired.faces())
+tet = tetgen.TetGen(repaired.vertices, repaired.cells)
 tet.tetrahedralize(order=1, mindihedral=20, minratio=1.5)
 tmesh = vedo.TetMesh(tet.grid)
 
 # save it to disk
-#tmesh.write("my_tetmesh.vtk")
+# tmesh.write("my_tetmesh.vtu")
 
 plt = vedo.Plotter(N=3, axes=1)
 plt.at(0).show("Original mesh", amesh)
