@@ -15,24 +15,23 @@ for t in np.arange(0, 20, dt):
     vel.append(mag(v))
 
 # Plot the trajectory in 3D space
-line = Line(pts).lw(2).cmap("winter", vel).add_scalarbar("speed")
+line = Line(pts).lw(2)
+line.cmap("winter", vel).add_scalarbar("speed")
 line.add_shadow("x",   3, alpha=0.2)
 line.add_shadow("z", -25, alpha=0.2)
-pt = Point(pts[0], c="red4", r=12).add_trail(lw=4)
 
-def loop_func(event):
-    global i
-    if i < len(pts):
-        pt.pos(pts[i]).update_trail() # move the point
+pt = Point(pts[0]).color("red4").ps(12)
+pt.add_trail(lw=4).add_shadow("x", 3, alpha=0.5)
+pt.trail.add_shadow("x", 3, alpha=0.5)
+
+def loop_func(event): # move the point
+    if len(pts) > 0:
+        pos = pts.pop(0)
+        pt.pos(pos).update_trail().update_shadows()
         plt.render()
-        i += 1
-    else:
-        plt.timer_callback("stop", tid) # stop the timer
 
-i = 0
 plt = Plotter(axes=dict(xygrid=False))
-plt.show(line, pt, __doc__, viewup="z", interactive=False)
 plt.add_callback("timer", loop_func)
-tid = plt.timer_callback("start")
-plt.interactive().close()
-
+plt.timer_callback("start")
+plt.show(line, pt, __doc__, viewup="z")
+plt.close()
