@@ -2,7 +2,7 @@
 Press "b" to compute the magnetic field"""
 import numpy as np
 from vedo import settings, mag, utils
-from vedo import Arrows, Points, StreamLines, Axes, Plotter, Text2D, Circle
+from vedo import Arrows, Points, Axes, Plotter, Text2D, Circle
 
 def func(evt):
     if evt.keypress != "b":
@@ -11,7 +11,7 @@ def func(evt):
     txt.c('red5').background('yellow7')
     plt.render()
 
-    pts = sptool.spline().points() # extract the current spline
+    pts = sptool.spline().vertices # extract the current spline
     field = []
     for probe in probes:
         B = np.zeros(3)
@@ -37,8 +37,7 @@ def func(evt):
     isos.cmap("rainbow").lighting('off').alpha(0.5).add_scalarbar()
     isos.name = "Isosurfaces"
 
-    streamlines = StreamLines(
-    	domain,
+    streamlines = domain.compute_streamlines(
     	probes,
         max_propagation=0.5,
         initial_step_size=0.01,
@@ -46,7 +45,7 @@ def func(evt):
     )
     streamlines.c('black').linewidth(2)
     plt.remove("Arrows", "StreamLines", "Isosurfaces", "Axes")
-    plt.add(arrows, streamlines, isos,  Axes(streamlines))
+    plt.add(arrows, streamlines, isos,  Axes(streamlines)).render()
 
 
 probes = utils.pack_spheres([-2,2, -2,2, -2,2], radius=0.7)
