@@ -1,14 +1,15 @@
 """Double pendulum in 3D"""
 # Original idea and solution using sympy from:
 # https://www.youtube.com/watch?v=MtG9cueB548
+import time
 from vedo import *
 
 # Load the solution:
 x1, y1, z1,  x2, y2, z2 = np.load(download(dataurl+'3Dpen.npy'))
 p1, p2 = np.c_[x1,y1,z1], np.c_[x2,y2,z2]
 
-ball1 = Sphere(c="green5", r=0.1, pos=p1[0])
-ball2 = Sphere(c="blue5",  r=0.1, pos=p2[0])
+ball1 = Sphere(p1[0], r=0.1).color("green5")
+ball2 = Sphere(p2[0], r=0.1).color("blue5")
 
 ball1.add_shadow('z', -3)
 ball2.add_shadow('z', -3)
@@ -18,8 +19,8 @@ ball2.add_trail(n=10)
 ball1.trail.add_shadow('z', -3) # make trails project a shadow too
 ball2.trail.add_shadow('z', -3)
 
-rod1 = Line([0,0,0], ball1, lw=4)
-rod2 = Line(ball1, ball2, lw=4)
+rod1 = Line([0,0,0], ball1, lw=4).add_shadow('z', -3)
+rod2 = Line(ball1, ball2, lw=4).add_shadow('z', -3)
 
 axes = Axes(xrange=(-3,3), yrange=(-3,3), zrange=(-3,3))
 
@@ -31,15 +32,16 @@ i = 0
 for b1, b2 in zip(p1,p2):
     ball1.pos(b1)
     ball2.pos(b2)
-    rod1.stretch([0,0,0], b1)
-    rod2.stretch(b1, b2)
-    ball1.update_shadows().update_trail()
-    ball2.update_shadows().update_trail()
-    ball1.trail.update_shadows()
-    ball2.trail.update_shadows()
+    ball1.update_trail().update_shadows()
+    ball2.update_trail().update_shadows()
+    rod1.vertices = [[0,0,0], b1]
+    rod2.vertices = [b1, b2]
+    rod1.update_shadows()
+    rod2.update_shadows()
     plt.render()
-    i+=1
-    if i > 150:
+    time.sleep(0.03)
+    i += 1
+    if i > 100:
         break
 
 plt.interactive().close()
