@@ -7,7 +7,7 @@ tet = vedo.TetMesh(vedo.dataurl+'earth_model.vtu')
 conductor = tet.clone().threshold('cell_scalars', above=0, below=4)
 
 # Crop the initial mesh
-box = vedo.Box(size=[503500, 505000, 6414000, 6417000, -1830, 600])
+box = vedo.Box([503500, 505000, 6414000, 6417000, -1830, 600])
 tet.cut_with_mesh(box, whole_cells=True)
 
 # We need to build a look up table for our color bar
@@ -26,21 +26,25 @@ lut_table = [
     (13.0, 'lime',       1, "Layer^E"),
     (15.0, 'seagreen',   1, "Layer^V"),
 ]
-lut = vedo.build_lut(lut_table)
+lut = vedo.build_lut(lut_table, interpolate=1)
 
-msh = tet.tomesh(shrink=0.95).cmap(lut, 'cell_scalars', on='cells')
+msh = tet.tomesh(shrink=0.95, fill=True)
+msh.cmap(lut, 'cell_scalars', on='cells')
 msh.add_scalarbar3d(
     categories=lut_table,
-    pos=(505500, 6416900, -630),
+    pos=(505700, 6417950, -1630),
     title='Units',
     title_size=1.25,
     label_size=1.5,
     size=[100, 2200],
 )
-# put scalarbar vertical, tell camera to keep bounds into account
-msh.scalarbar.rotate_x(90, around='itself').rotate_z(60, around='itself')
-msh.scalarbar.use_bounds()
 
+# Put scalarbar vertical, tell camera to keep bounds into account
+# msh.scalarbar.rotate_x(90).rotate_z(60).use_bounds(True)
+
+# OR: use clone2d to create a 2D scalarbar from the 3D one
+msh.scalarbar = msh.scalarbar.clone2d(pos=[0.7,-0.95], size=0.3)
+ 
 # Create cmap for conductor
 cond = conductor.tomesh().cmap(lut, 'cell_scalars', on='cells')
 
@@ -66,4 +70,4 @@ axes = vedo.Axes(
 )
 
 vedo.show(msh, cond, axes, __doc__, size=(1305, 1020),
-          roll=-80, azimuth=50, elevation=-10, zoom=1.25).close()
+          roll=-80, azimuth=50, elevation=-10, zoom=1.2).close()
