@@ -6,7 +6,7 @@ n = 20000
 f1 = 0.005  # control the tetras resolution
 f2 = 0.15   # control the nr of seeds
 
-tmesh = TetMesh(dataurl + "limb_ugrid.vtk")
+tmesh = TetMesh(dataurl + "limb.vtu")
 surf = tmesh.tomesh(fill=False)
 txt = Text2D(__doc__, font="Brachium")
 
@@ -15,11 +15,10 @@ seeds = surf.clone().subsample(f2).ps(10).c("black")
 
 # assign to each tetrahedron the id of the closest seed point
 cids = []
-for p in tmesh.cell_centers():
+for p in tmesh.cell_centers:
     cid = seeds.closest_point(p, return_point_id=True)
     cids.append(cid)
 tmesh.celldata["fragment"] = cids
-# tmesh.celldata.select("fragment")# bug, has no effect, needs name=...
 
 pieces = []
 for i in range(seeds.npoints):
