@@ -1,7 +1,5 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 """
 Command Line Interface module
 -----------------------------
@@ -27,26 +25,17 @@ import os
 import sys
 import numpy as np
 
-try:
-    import vedo.vtkclasses as vtk
-except ImportError:
-    import vtkmodules.all as vtk
-
-import vedo
 from vedo.utils import humansort
-from vedo.utils import is_sequence
-from vedo.utils import print_info
-from vedo import __version__
-from vedo import file_io
-from vedo import load
-from vedo import settings
 from vedo.colors import get_color, printc
 from vedo.mesh import Mesh
-from vedo.picture import Picture
+from vedo.image import Image
 from vedo.plotter import Plotter
-from vedo.tetmesh import TetMesh
-from vedo.ugrid import UGrid
+from vedo.grids import UnstructuredGrid, TetMesh
 from vedo.volume import Volume
+
+import vedo
+from vedo import __version__
+from vedo import file_io, load, settings
 from vedo import applications
 
 __all__ = []
@@ -87,7 +76,7 @@ def execute_cli():
     elif len(args.files) == 0:
         system_info()
         printc(
-            ":idea: No input files. Try:\n> vedo https://vedo.embl.es/examples/data/panther.stl.gz",
+            ":idea: No input files? Try:\n vedo https://vedo.embl.es/examples/data/panther.stl.gz",
             c="y",
         )
 
@@ -133,7 +122,7 @@ def get_parser():
     pr.add_argument("--search-vtk",       type=str, help="search examples for the input vtk class", default='', metavar='')
     pr.add_argument("--search-code",      type=str, help="search keyword in source code", default='', metavar='')
     pr.add_argument("--reload",                     help="reload the file, ignoring any previous download", action="store_true")
-    pr.add_argument("--info", nargs='*',            help="get an info printout of the input file(s)")
+    pr.add_argument("--info", nargs='*',            help="get an info printout of the current installation")
     pr.add_argument("--convert", nargs='*',         help="input file(s) to be converted")
     pr.add_argument("--to",               type=str, help="convert to this target format", default='vtk', metavar='')
     pr.add_argument("--image",                      help="image mode for 2d objects", action="store_true")
@@ -144,31 +133,16 @@ def get_parser():
 
 #################################################################################################
 def system_info():
-    for i in range(2, len(sys.argv)):
-        file = sys.argv[i]
-        try:
-            A = load(file)
-            if isinstance(A, np.ndarray):
-                print_info(A)
-            elif is_sequence(A):
-                for a in A:
-                    print_info(a)
-            else:
-                print_info(A)
-        except:
-            vedo.logger.error(f"Could not load {file}, skip.")
+    from vtkmodules.all import vtkVersion
 
-    printc("_" * 65, bold=0)
-    printc("vedo version      :", __version__, invert=1, end="   ")
-    printc("https://vedo.embl.es", underline=1, italic=1)
-    printc("vtk version       :", vtk.vtkVersion().GetVTKVersion())
+    printc(f"vedo version      : {__version__}  (https://vedo.embl.es) ".ljust(65), invert=1)
+    printc("vtk version       :", vtkVersion().GetVTKVersion())
     printc("numpy version     :", np.__version__)
     printc("python version    :", sys.version.replace("\n", ""))
     printc("python interpreter:", sys.executable)
-    printc("vedo installation :", vedo.installdir)
+    printc("installation point:", vedo.installdir[:70])
     try:
         import platform
-
         printc(
             "system            :",
             platform.system(),
@@ -179,20 +153,8 @@ def system_info():
     except ModuleNotFoundError:
         pass
 
-    try:
-        from screeninfo import get_monitors
-
-        for m in get_monitors():
-            pr = "         "
-            if m.is_primary:
-                pr = "(primary)"
-            printc(f"monitor {pr} : {m.name}, resolution=({m.width}, {m.height}), x={m.x}, y={m.y}")
-    except ModuleNotFoundError:
-        printc('monitor           : info is unavailable. Try "pip install screeninfo".')
-
     try:
         import k3d
-
         printc("k3d version       :", k3d.__version__, bold=0, dim=1)
     except ModuleNotFoundError:
         pass
@@ -222,37 +184,42 @@ def exe_run(args):
     matching = list(sorted(matching))
     nmat = len(matching)
     if nmat == 0:
-        printc(f":sad: No matching example found containing string: {args.run}", c=1)
-        printc(" Current installation directory is:", vedo.installdir, c=1)
-        sys.exit(1)
+        printc(f":sad: No matching example with name: {args.run}", c="y")
+        # Nothing found, try to search for a script content:
+        args.search = args.run
+        args.run = ""
+        exe_search(args)
+        return
 
     if nmat > 1:
-        printc(f"\n:target: Found {nmat} matching scripts:", c="y", italic=1)
+        printc(f":target: Found {nmat} scripts containing string '{args.run}':", c="c")
         args.full_screen = True  # to print out the one line description
 
     if args.full_screen:  # -f option not to dump the full code but just the first line
-        for mat in matching[:25]:
-            printc(os.path.basename(mat).replace(".py", ""), c="y", italic=1, end=" ")
+        for mat in matching[:30]:
+            printc(os.path.basename(mat).replace(".py", ""), c="c", end=" ")
             with open(mat, "r", encoding="UTF-8") as fm:
                 lline = "".join(fm.readlines(60))
-                lline = lline.replace("\n", " ").replace("'", "").replace('"', "").replace("-", "")
-                line = lline[:56]  # cut
-                if line.startswith("from"):
-                    line = ""
-                if line.startswith("import"):
-                    line = ""
-                if len(lline) > len(line):
+                maxidx1 = lline.find("import ")
+                maxidx2 = lline.find("from vedo")
+                maxid = min(maxidx1, maxidx2)
+                lline = lline[:maxid]  # cut where the code starts
+                lline = lline.replace("\n", " ").replace("'", "").replace('"', "")
+                lline = lline.replace("#", "").replace("-", "").replace("  ", " ")
+                line = lline[:68]  # cut long lines
+                if len(lline) > len(line) + 1:
                     line += ".."
                 if len(line) > 5:
-                    printc("-", line, c="y", bold=0, italic=1)
+                    printc("-", line, c="c", bold=0, italic=1, dim=1)
                 else:
                     print()
 
-    if nmat > 25:
-        printc("...", c="y")
+    if nmat > 30:
+        printc(f"... (and {nmat-30} more)", c="c")
 
     if nmat > 1:
-        sys.exit(0)
+        printc(":idea: Type 'vedo -r <name>' to run one of them", bold=0, c="c")
+        return
 
     if not args.full_screen:  # -f option not to dump the full code
         with open(matching[0], "r", encoding="UTF-8") as fm:
@@ -262,20 +229,26 @@ def exe_run(args):
         from pygments import highlight
         from pygments.lexers import Python3Lexer
         from pygments.formatters import Terminal256Formatter
+        from pygments.styles import STYLE_MAP
 
-        # from pygments.styles import STYLE_MAP
-        # print(STYLE_MAP.keys())
-        result = highlight(code, Python3Lexer(), Terminal256Formatter(style="zenburn"))
+        # print("Terminal256Formatter STYLE_MAP", STYLE_MAP.keys())
+        if "zenburn" in STYLE_MAP.keys():
+            tform = Terminal256Formatter(style="zenburn")
+        elif "monokai" in STYLE_MAP.keys():
+            tform = Terminal256Formatter(style="monokai")
+        else:        
+            tform = Terminal256Formatter()
+        result = highlight(code, Python3Lexer(), tform)
         print(result, end="")
 
     printc("(" + matching[0] + ")", c="y", bold=0, italic=1)
-    os.system("python " + matching[0])
+    os.system(f"python {matching[0]} || python3 {matching[0]}")
 
 
 ################################################################################################
 def exe_convert(args):
 
-    allowedexts = [
+    allowed_exts = [
         "vtk",
         "vtp",
         "vtu",
@@ -284,6 +257,7 @@ def exe_convert(args):
         "ply",
         "stl",
         "obj",
+        "off",
         "byu",
         "xml",
         "vti",
@@ -299,8 +273,8 @@ def exe_convert(args):
 
     target_ext = args.to.lower()
 
-    if target_ext not in allowedexts:
-        printc(f":sad: Sorry target cannot be {target_ext}\nMust be {allowedexts}", c=1)
+    if target_ext not in allowed_exts:
+        printc(f":sad: Sorry target cannot be {target_ext}\nMust be {allowed_exts}", c='r')
         sys.exit()
 
     for f in args.convert:
@@ -358,7 +332,7 @@ def exe_search(args):
                             pattern, "\x1b[4m\x1b[1m" + pattern + "\x1b[0m\u001b[33m"
                         )
                         print(f"\u001b[33m{i}\t{line}\x1b[0m", end="")
-                        # printc(i, line, c='o', bold=False, end='')
+                        # printc(i, line, c='y', bold=False, end='')
     else:
         printc("Please use at least 4 letters in keyword search!", c="r")
 
@@ -468,7 +442,7 @@ def exe_search_vtk(args):
 
     xref_url = "https://raw.githubusercontent.com/Kitware/vtk-examples/gh-pages/src/Coverage/vtk_vtk-examples_xref.json"
 
-    def download_file(dl_path, dl_url, overwrite=False):
+    def _download_file(dl_path, dl_url, overwrite=False):
         file_name = dl_url.split("/")[-1]
         # Create necessary sub-directories in the dl_path (if they don't exist).
         Path(dl_path).mkdir(parents=True, exist_ok=True)
@@ -481,7 +455,7 @@ def exe_search_vtk(args):
                 raise RuntimeError(f"Failed to download {dl_url}. {e.reason}")
         return path
 
-    def get_examples(d, vtk_class, lang):
+    def _get_examples(d, vtk_class, lang):
         try:
             kv = d[vtk_class][lang].items()
         except KeyError as e:
@@ -493,18 +467,18 @@ def exe_search_vtk(args):
 
     vtk_class, language, all_values, number = args.search_vtk, "Python", True, 10000
     tmp_dir = tempfile.gettempdir()
-    path = download_file(tmp_dir, xref_url, overwrite=False)
+    path = _download_file(tmp_dir, xref_url, overwrite=False)
     if not path.is_file():
         print(f"The path: {str(path)} does not exist.")
 
     dt = datetime.today().timestamp() - os.path.getmtime(path)
     # Force a new download if the time difference is > 10 minutes.
     if dt > 600:
-        path = download_file(tmp_dir, xref_url, overwrite=True)
+        path = _download_file(tmp_dir, xref_url, overwrite=True)
     with open(path, "r", encoding="UTF-8") as json_file:
         xref_dict = json.load(json_file)
 
-    total_number, examples = get_examples(xref_dict, vtk_class, language)
+    total_number, examples = _get_examples(xref_dict, vtk_class, language)
     if examples:
         if total_number <= number or all_values:
             print(
@@ -524,6 +498,9 @@ def exe_search_vtk(args):
 #################################################################################################################
 def exe_eog(args):
     # print("EOG emulator")
+    if settings.dry_run_mode >= 2:
+        print(f"EOG emulator in dry run mode {settings.dry_run_mode}. Skip.")
+        return
     settings.immediate_rendering = False
     settings.use_parallel_projection = True
     settings.enable_default_mouse_callbacks = False
@@ -576,7 +553,7 @@ def exe_eog(args):
                 ahl = plt.hover_legends[-1]
                 plt.remove(ahl)
                 plt.screenshot()  # writer
-                printc(":camera: Picture saved as screenshot.png")
+                printc(":camera: Image saved as screenshot.png")
                 plt.add(ahl)
                 return
             elif event.keypress == "h":
@@ -601,7 +578,7 @@ def exe_eog(args):
     for f in files:
         if os.path.isfile(f):
             try:
-                pic = Picture(f)
+                pic = Image(f)
                 if pic:
                     pics.append(pic)
             except:
@@ -657,6 +634,9 @@ def exe_eog(args):
 
 #################################################################################################################
 def draw_scene(args):
+    if settings.dry_run_mode >= 2:
+        print(f"draw_scene called in dry run mode {settings.dry_run_mode}. Skip.")
+        return
 
     nfiles = len(args.files)
     if nfiles == 0:
@@ -694,15 +674,19 @@ def draw_scene(args):
         if nfiles < 201:
             N = nfiles
         if nfiles > 200:
-            printc(":lightning: Warning: option '-n' allows a maximum of 200 files", c=1)
-            printc("         you are trying to load ", nfiles, " files.\n", c=1)
+            printc(":lightning: Warning: option '-n' allows a maximum of 200 files", c="y")
+            printc("         you are trying to load ", nfiles, " files.\n", c="y")
             N = 200
         if N > 4:
             settings.use_depth_peeling = False
 
-        plt = Plotter(size=wsize, N=N, 
-                      bg=args.background, bg2=args.background_grad,
-                      sharecam=sharecam)
+        plt = Plotter(
+            size=wsize,
+            N=N,
+            bg=args.background,
+            bg2=args.background_grad,
+            sharecam=sharecam,
+        )
         settings.immediate_rendering = False
         plt.axes = args.axes_type
         for i in range(N):
@@ -715,10 +699,6 @@ def draw_scene(args):
         plt.axes = args.axes_type
         plt.add_hover_legend()
 
-    wire = False
-    if args.wireframe:
-        wire = True
-
     ##########################################################
     # special case of SLC/TIFF volumes with -g option
     if args.ray_cast_mode:
@@ -733,7 +713,6 @@ def draw_scene(args):
         sp = vol.spacing()
         vol.spacing([sp[0] * args.x_spacing, sp[1] * args.y_spacing, sp[2] * args.z_spacing])
         vol.mode(int(args.mode)).color(args.cmap).jittering(True)
-        vol.lighting(args.lighting)
         plt = applications.RayCastPlotter(vol)
         plt.show(viewup="z", interactive=True).close()
         return
@@ -762,12 +741,12 @@ def draw_scene(args):
             bg="white",
             bg2="lb",
             use_slider3d=useSlider3D,
-            cmaps=[args.cmap, "Spectral_r", "hot_r", "bone_r", "gist_ncar_r"],
-            alpha=args.alpha,
             axes=args.axes_type,
             clamp=True,
-            size=(1000, 800),
+            size=(1350, 1000),
         )
+        plt += vedo.Text2D(args.files[0], pos="top-left", font="VictorMono", s=1, c="k")
+        plt.show()
         return
 
     ########################################################################
@@ -799,10 +778,8 @@ def draw_scene(args):
         vol.cmap("bone_r")
         sp = vol.spacing()
         vol.spacing([sp[0] * args.x_spacing, sp[1] * args.y_spacing, sp[2] * args.z_spacing])
-        vedo.plotter_instance = None  # reset
-
-        plt = applications.Slicer2DPlotter(vol, axes=7)
-        plt.close()
+        vedo.plotter_instance = applications.Slicer2DPlotter(vol)
+        vedo.plotter_instance.show().close()
         return
 
     ########################################################################
@@ -817,6 +794,14 @@ def draw_scene(args):
     ):
         # print('DEBUG normal mode for single VOXEL file with Isosurface Slider mode')
         vol = file_io.load(args.files[0], force=args.reload)
+
+        if vol.shape[2] == 1:
+            # print('DEBUG It is a 2D image!')
+            img = vedo.Image(args.files[0])
+            plt = vedo.Plotter().parallel_projection()
+            plt.show(img, zoom="tightest", mode="image").close()
+            return
+
         sp = vol.spacing()
         vol.spacing([sp[0] * args.x_spacing, 
                      sp[1] * args.y_spacing, 
@@ -824,10 +809,9 @@ def draw_scene(args):
         if not args.color:
             args.color = "gold"
         plt = applications.IsosurfaceBrowser(
-            vol, c=args.color, cmap=args.cmap, 
-            precompute=False, progress=True, use_gpu=True,
+            vol, c=args.color, cmap=args.cmap, precompute=False, use_gpu=True
         )
-        plt.show(zoom=args.zoom, viewup="z")
+        plt.show(zoom=args.zoom, viewup="z").close()
         return
 
     ########################################################################
@@ -840,19 +824,24 @@ def draw_scene(args):
             interactor_mode = "image"
 
         ##########################################################
-        # loading a full scene
-        if ".npy" in args.files[0] or ".npz" in args.files[0] and nfiles == 1:
-
-            objct = file_io.load(args.files[0], force=args.reload)
-            if isinstance(objct, Plotter):  # loading a full scene
-                objct.show(mode=interactor_mode)
-            else:  # loading a set of meshes
-                plt.show(objct, mode=interactor_mode)
-            return
+        # loading a full scene or list of objects
+        if ".npy" in args.files[0] or ".npz" in args.files[0]:
+            try: # full scene
+                plt = file_io.import_window(args.files[0])
+                plt.show(mode=interactor_mode).close()
+                return
+            except KeyError: # list of objects, create Assembly
+                objs = vedo.Assembly(args.files[0])
+                for i, ob in enumerate(objs):
+                    if ob:
+                        ob.c(i)
+                plt = Plotter()
+                plt.show(objs, mode=interactor_mode).close()
+                return
         #########################################################
 
         ds = 0
-        actors = []
+        objs = []
 
         for i in range(N):
             f = args.files[i]
@@ -861,46 +850,61 @@ def draw_scene(args):
             if args.color is None and N > 1:
                 colb = i
 
-            actor = load(f, force=args.reload)
+            obj = load(f, force=args.reload)
 
-            if isinstance(actor, (TetMesh, UGrid)):
-                actor = actor.tomesh().shrink(0.975).c(colb).alpha(args.alpha)
+            if isinstance(obj, (TetMesh, UnstructuredGrid)):
+                # obj = obj#.shrink(0.95)
+                obj.c(colb).alpha(args.alpha)
 
-            elif isinstance(actor, vedo.Points):
-                actor.c(colb).alpha(args.alpha).wireframe(wire).lighting(args.lighting)
-                if args.flat:
-                    actor.flat()
-                else:
-                    actor.phong()
+            elif isinstance(obj, vedo.Points):
+                obj.c(colb).alpha(args.alpha)
+
+                try:
+                    obj.wireframe(args.wireframe)
+                    if args.flat:
+                        obj.flat()
+                    else:
+                        obj.phong()
+                except AttributeError:
+                    pass
+
+                obj.lighting(args.lighting)
 
                 if i == 0 and args.texture_file:
-                    actor.texture(args.texture_file)
+                    obj.texture(args.texture_file)
 
                 if args.point_size > 0:
-                    actor.ps(args.point_size)
+                    obj.ps(args.point_size)
 
                 if args.cmap != "jet":
-                    actor.cmap(args.cmap)
+                    obj.cmap(args.cmap)
 
                 if args.showedges:
                     try:
-                        actor.GetProperty().SetEdgeVisibility(1)
-                        actor.GetProperty().SetLineWidth(0.1)
-                        actor.GetProperty().SetRepresentationToSurface()
+                        obj.GetProperty().SetEdgeVisibility(1)
+                        obj.GetProperty().SetLineWidth(0.1)
+                        obj.GetProperty().SetRepresentationToSurface()
                     except AttributeError:
                         pass
 
-            actors.append(actor)
+            objs.append(obj)
 
             if args.multirenderer_mode:
                 try:
-                    ds = actor.diagonal_size() * 3
+                    ds = obj.diagonal_size() * 3
                     plt.camera.SetClippingRange(0, ds)
-                    plt.show(actor, at=i, interactive=False,
-                             zoom=args.zoom, mode=interactor_mode)
-                    plt.actors = actors
+                    plt.reset_camera()
+                    # plt.render()
+                    plt.show(
+                        obj,
+                        at=i,
+                        interactive=False,
+                        zoom=args.zoom,
+                        mode=interactor_mode,
+                    )
+
                 except AttributeError:
-                    # wildcards in quotes make glob return actor as a list :(
+                    # wildcards in quotes make glob return obj as a list :(
                     vedo.logger.error("Please do not use wildcards within single or double quotes")
 
         if args.multirenderer_mode:
@@ -911,10 +915,10 @@ def draw_scene(args):
         else:
 
             # scene is empty
-            if all(a is None for a in actors):
+            if all(a is None for a in objs):
                 vedo.logger.error("Could not load file(s). Quit.")
                 return
-            plt.show(actors, interactive=True, zoom=args.zoom, mode=interactor_mode)
+            plt.show(objs, interactive=True, zoom=args.zoom, mode=interactor_mode)
         return
 
     ########################################################################
@@ -927,7 +931,7 @@ def draw_scene(args):
         acts = load(args.files, force=args.reload)
         plt += acts
         for a in acts:
-            if hasattr(a, "c"):  # Picture doesnt have it
+            if hasattr(a, "c"):  # Image doesnt have it
                 a.c(args.color)
 
             if args.point_size > 0:
